# Game server

This is a collection of scripts to deploy game servers on Debian 11. All game
servers are wrapped in SystemD units and can be controlled by systemctl.

It also comes with a web front end which features the games hosted as well as
their respective download link. It also displays server stats and has an admin
panel for game servers that have interactive shells.

The following games are deployed:

* Armagetron Advanced
* Bzflag
* Hedgewars
* Lix
* Mindustry
* Minetest (Blockbomber mod)
* Odamex
* OpenHV
* OpenSpades
* OpenSoldat
* Shattered Paradise
* SuperTuxKart
* Super Tux Party
* Teeworlds (optionally as DDrace)
* UFO: Alien Invasion
* Unvanquished
* Xonotic (optionally as Battle Royale)

It is based on https://git.libregaming.org/c/onFOSS-LAN-Serverconfiguration

## Installation

The main script is `deploy.sh`. You only need to give if your domain name and your own name.
```
DOMAINNAME=play.jarno.ca HOSTEDBYNAME=DeathByDenim ./deploy.sh
```
This will download all the game servers, install them, configure them, and start them up. It should take less than an hour for all game servers to be up and running.

It also retrieves a certificate for Let's Encrypt for the web interface. If you don't want the certificate, you can also specify `NOSSL=1`.

There is also support for generating just the website without the game server which is useful if you want to host the website somewhere else while your main server is down.
```
DOMAINNAME=play.jarno.ca HOSTEDBYNAME=DeathByDenim ./pack_web_offline.sh
```
The webpage will display "OFFLINE" and not attempt to show the server stats.

The password for the admin panel as well as for game servers that support admin password is stored in `/etc/gameserverpassword`. The username for the admin panel is just `onfoss`.

## Website

The website is generated using Jekyll which uses a config.yml that is generated by the deploy script. Additionally, there is a YAML file called events.yml in the _data directory where events are stored. The formatting is:

```
- date: 2022-12-17T14:00:00UTC
  intro: "onFOSS-LAN hosted by DeathByDenim"
  games:
    - time: "14:00"
      title: "Get together"
    - time: "14:30"
      title: "Doom (ODAMEX) XMAS mod"
    - time: "15:15"
      title: "Teeworlds"
      tournament: true
    - time: "16:00"
      title: "OpenSpades"
    - time: "17:00"
      title: "Break"
    - time: "18:00"
      title: "Lix"
    - time: "18:30"
      title: "Free Play!"
      extras: ["Shattered Paradise"]
```
Each game must have a title and it optionally can have a time as well. The optional field extras lists games that were played as part of a bigger category, in this example the free play section.

Finally, you can also specify tournament which will make this game appear in the tournament page.

## Repository

The main version of this git repository is on [git.libregaming.org](https://git.libregaming.org/DeathByDenim/gameserver). There is a mirror on [Github](https://github.com/DeathByDenim/gameserver)
